==> esp32c3-0.2.0.crate: esp32c3-0.2.0/src/sensitive/backup_bus_pms_monitor_3.rs <==
#[doc = "Register `BACKUP_BUS_PMS_MONITOR_3` reader"]
pub struct R(crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR` reader - backup_bus_pms_monitor_violate_haddr"]
pub struct BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R(crate::FieldReader<u32, u32>);
impl BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R {
    pub(crate) fn new(bits: u32) -> Self {
        BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - backup_bus_pms_monitor_violate_haddr"]
    #[inline(always)]
    pub fn backup_bus_pms_monitor_violate_haddr(&self) -> BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R {
        BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R::new((self.bits & 0xffff_ffff) as u32)
    }
}
#[doc = "SENSITIVE_BACKUP_BUS_PMS_MONITOR_3_REG\n\nThis register you can [`read`](crate::generic::Reg::read). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [backup_bus_pms_monitor_3](index.html) module"]
pub struct BACKUP_BUS_PMS_MONITOR_3_SPEC;
impl crate::RegisterSpec for BACKUP_BUS_PMS_MONITOR_3_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [backup_bus_pms_monitor_3::R](R) reader structure"]
impl crate::Readable for BACKUP_BUS_PMS_MONITOR_3_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets BACKUP_BUS_PMS_MONITOR_3 to value 0"]
impl crate::Resettable for BACKUP_BUS_PMS_MONITOR_3_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp32c3-0.4.0.crate: esp32c3-0.4.0/src/sensitive/backup_bus_pms_monitor_3.rs <==
#[doc = "Register `BACKUP_BUS_PMS_MONITOR_3` reader"]
pub struct R(crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<BACKUP_BUS_PMS_MONITOR_3_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Field `BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR` reader - backup_bus_pms_monitor_violate_haddr"]
pub struct BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R(crate::FieldReader<u32, u32>);
impl BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R {
    #[inline(always)]
    pub(crate) fn new(bits: u32) -> Self {
        BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R {
    type Target = crate::FieldReader<u32, u32>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl R {
    #[doc = "Bits 0:31 - backup_bus_pms_monitor_violate_haddr"]
    #[inline(always)]
    pub fn backup_bus_pms_monitor_violate_haddr(&self) -> BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R {
        BACKUP_BUS_PMS_MONITOR_VIOLATE_HADDR_R::new(self.bits)
    }
}
#[doc = "SENSITIVE_BACKUP_BUS_PMS_MONITOR_3_REG\n\nThis register you can [`read`]
(crate::generic::Reg::read). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [backup_bus_pms_monitor_3]
(index.html) module"]
pub struct BACKUP_BUS_PMS_MONITOR_3_SPEC;
impl crate::RegisterSpec for BACKUP_BUS_PMS_MONITOR_3_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [backup_bus_pms_monitor_3::R]
(R) reader structure"]
impl crate::Readable for BACKUP_BUS_PMS_MONITOR_3_SPEC {
    type Reader = R;
}
#[doc = "`reset()` method sets BACKUP_BUS_PMS_MONITOR_3 to value 0"]
impl crate::Resettable for BACKUP_BUS_PMS_MONITOR_3_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
